// java wrapper for vtkBlankStructuredGridWithImage object
//

package vtk;
import vtk.*;

public class vtkBlankStructuredGridWithImage extends vtkStructuredGridAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetBlankingInputData_2(vtkImageData id0);
  public void SetBlankingInputData(vtkImageData id0)
    { SetBlankingInputData_2(id0); }

  private native long GetBlankingInput_3();
  public vtkImageData GetBlankingInput() {
    long temp = GetBlankingInput_3();

    if (temp == 0) return null;
    return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkBlankStructuredGridWithImage() { super(); }

  public vtkBlankStructuredGridWithImage(long id) { super(id); }
  public native long   VTKInit();

}
